summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
Diffstat (limited to 'png.h')
-rw-r--r--png.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/png.h b/png.h
index 49da7d690..51be7b2d1 100644
--- a/png.h
+++ b/png.h
@@ -1,6 +1,6 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.0.53beta01 - January 14, 2010
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -10,7 +10,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.0.53beta01 - January 14, 2010: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -286,7 +286,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.0.53beta01, January 14, 2010, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -398,13 +398,13 @@
* Y2K compliance in libpng:
* =========================
*
- * January 14, 2010
+ * January 27, 2010
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.0.53beta01 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -460,9 +460,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.0.53beta01"
+#define PNG_LIBPNG_VER_STRING "1.0.53beta02"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.0.53beta01 - January 14, 2010\n"
+ " libpng version 1.0.53beta02 - January 27, 2010\n"
#define PNG_LIBPNG_VER_SONUM 0
#define PNG_LIBPNG_VER_DLLNUM 10
@@ -475,7 +475,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 01
+#define PNG_LIBPNG_VER_BUILD 02
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -1531,7 +1531,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_0_53beta01;
+typedef png_structp version_1_0_53beta02;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,6 +1,6 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.0.53beta01 - January 14, 2010
+ * libpng version 1.0.53beta02 - January 27, 2010
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -10,7 +10,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.0.53beta01 - January 14, 2010: Glenn
+ * libpng versions 0.97, January 1998, through 1.0.53beta02 - January 27, 2010: Glenn
* See also "Contributing Authors", below.
*
@@ -286,7 +286,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.0.53beta01, January 14, 2010, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.0.53beta02, January 27, 2010, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -398,13 +398,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.0.53beta01 are Y2K compliant. It is my belief that earlier
+ * upward through 1.0.53beta02 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*